# InvoiceItem


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**integration_id__ns** | **str** | ID of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**integration_status__ns** | **str** | Status of the invoice item&#39;s synchronization with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**sync_date__ns** | **str** | Date when the invoice item was synchronized with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**accounting_code** | **str** | The accounting code associated with the invoice item. | [optional] 
**adjustment_liability_accounting_code** | **str** | The accounting code for adjustment liability.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**adjustment_revenue_accounting_code** | **str** | The accounting code for adjustment revenue.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**applied_to_item_id** | **str** | The unique ID of the invoice item that the discount charge is applied to. | [optional] 
**available_to_credit_amount** | **decimal.Decimal** | The amount of the invoice item that is available to credit. | [optional] 
**balance** | **decimal.Decimal** | The balance of the invoice item. | [optional] 
**booking_reference** | **str** | The booking reference of the invoice item. | [optional] 
**charge_amount** | **decimal.Decimal** | The amount of the charge.   This amount does not include taxes regardless if the charge&#39;s tax mode is inclusive or exclusive.  | [optional] 
**charge_date** | **str** | The date when the invoice item is charged, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. | [optional] 
**charge_description** | **str** | The description of the charge. | [optional] 
**charge_id** | **str** | The unique ID of the charge. | [optional] 
**charge_name** | **str** | The name of the charge. | [optional] 
**charge_type** | [**ChargeType**](ChargeType.md) |  | [optional] 
**contract_asset_accounting_code** | **str** | The accounting code for contract asset.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**contract_liability_accounting_code** | **str** | The accounting code for contract liability.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**contract_recognized_revenue_accounting_code** | **str** | The accounting code for contract recognized revenue.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**deferred_revenue_accounting_code** | **str** | The deferred revenue accounting code associated with the invoice item. **Note:** This field is only available if you have Zuora Finance enabled. | [optional] 
**description** | **str** | The description of the invoice item. | [optional] 
**exclude_item_billing_from_revenue_accounting** | **bool** | The flag to exclude the invoice item from revenue accounting.  **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**id** | **str** | Item ID. | [optional] 
**invoice_schedule_id** | **str** | The ID of the invoice schedule item by which Invoice Schedule Item the invoice item is generated by when the Invoice Schedule Item is executed. **Note**: This field is available only if you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Billing_Schedule\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing Schedule&lt;/a&gt; feature in the **Early Adopter** phase enabled. | [optional] 
**invoice_schedule_item_id** | **str** | The ID of the invoice schedule item associated with the invoice item. **Note**: This field is available only if you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Billing_Schedule\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing Schedule&lt;/a&gt; feature in the **Early Adopter** phase enabled. | [optional] 
**item_type** | **str** | The type of the invoice item. | [optional] 
**processing_type** | [**BillingDocumentItemProcessingType**](BillingDocumentItemProcessingType.md) |  | [optional] 
**product_name** | **str** | Name of the product associated with this item. | [optional] 
**product_rate_plan_charge_id** | **str** | The ID of the product rate plan charge that the invoice item is created from. | [optional] 
**purchase_order_number** | **str** | The purchase order number associated with the invoice item. | [optional] 
**quantity** | **float** | The quantity of this item, in the configured unit of measure for the charge. | [optional] 
**recognized_revenue_accounting_code** | **str** | The recognized revenue accounting code associated with the invoice item. **Note:** This field is only available if you have Zuora Finance enabled. | [optional] 
**rev_rec_code** | **str** | The revenue recognition code. | [optional] 
**rev_rec_trigger_condition** | [**RevRecTrigger**](RevRecTrigger.md) |  | [optional] 
**revenue_recognition_rule_name** | **str** | The revenue recognition rule of the invoice item. **Note:** This field is only available if you have Zuora Finance enabled. | [optional] 
**service_end_date** | **date** | The end date of the service period for this item, i.e., the last day of the service period, as _yyyy-mm-dd_. | [optional] 
**service_start_date** | **date** | The start date of the service period for this item, as _yyyy-mm-dd_. For a one-time fee item, the date of the charge. | [optional] 
**ship_to_contact_id** | **str** | The ID of the ship-to contact associated with the invoice item. | [optional] 
**sku** | **str** | The SKU of the invoice item. | [optional] 
**sold_to_contact_id** | **str** | The ID of the sold-to contact associated with the invoice item. **Note**: If you have the Flexible Billing Attributes feature disabled, the value of this field is &#x60;null&#x60;. | [optional] 
**sold_to_contact_snapshot_id** | **str** | The ID of the sold-to contact snapshot associated with the invoice item. **Note**: If you have the Flexible Billing Attributes feature disabled, the value of this field is &#x60;null&#x60;. | [optional] 
**source_item_type** | [**BillingDocumentItemSourceType**](BillingDocumentItemSourceType.md) |  | [optional] 
**subscription_id** | **str** | The ID of the subscription for this item. | [optional] 
**subscription_name** | **str** | The name of the subscription for this item. | [optional] 
**tax_amount** | **decimal.Decimal** | Tax applied to the charge. | [optional] 
**tax_code** | **str** | The tax code of the invoice item. **Note** Only when taxation feature is enabled, this field can be presented. | [optional] 
**tax_mode** | [**TaxMode**](TaxMode.md) |  | [optional] 
**taxation_items** | [**TaxationItemsData**](TaxationItemsData.md) |  | [optional] 
**unbilled_receivables_accounting_code** | **str** | The accounting code for unbilled receivables.         **Note**: This field is only available if you have the Billing - Revenue Integration feature enabled.   | [optional] 
**unit_of_measure** | **str** | Unit used to measure consumption. | [optional] 
**unit_price** | **float** | The per-unit price of the invoice item. | [optional] 
**number_of_deliveries** | **float** | The number of delivery for charge.  **Note**: This field is available only if you have the Delivery Pricing feature enabled.  | [optional] 
**reflect_discount_in_net_amount** | **bool** | The flag to reflect Discount in Apply To Charge Net Amount.  | [optional] 

## Example

```python
from zuora_sdk.models.invoice_item import InvoiceItem

# TODO update the JSON string below
json = "{}"
# create an instance of InvoiceItem from a JSON string
invoice_item_instance = InvoiceItem.from_json(json)
# print the JSON string representation of the object
print(InvoiceItem.to_json())

# convert the object into a dict
invoice_item_dict = invoice_item_instance.to_dict()
# create an instance of InvoiceItem from a dict
invoice_item_from_dict = InvoiceItem.from_dict(invoice_item_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


